@@ -28,6 +28,12 @@
 
 /***************************************************************************/
 
+/**
+ * expr_tree_new_constant :
+ * @v :
+ *
+ * Absorb the value.
+ */
 ExprTree *
 expr_tree_new_constant (Value *v)
 {
@@ -366,26 +372,6 @@ expr_tree_equal (ExprTree const *a, ExprTree const *b)
 	return FALSE;
 }
 
-static Value *
-eval_funcall (EvalPos const *pos, ExprTree const *expr,
-	      ExprEvalFlags flags)
-{
-	FunctionEvalInfo ei;
-	FunctionDefinition *fd;
-	ExprList *args;
-
-	g_return_val_if_fail (pos != NULL, NULL);
-	g_return_val_if_fail (expr != NULL, NULL);
-
-	fd = expr->func.func;
-	ei.func_def = fd;
-	ei.pos = pos;
-	args = expr->func.arg_list;
-
-	/*if (flags & EVAL_PERMIT_NON_SCALAR)*/
-	return function_call_with_list (&ei, args);
-}
-
 /**
  * expr_implicit_intersection :
  * @ei: EvalInfo containing valid fd!
@@ -416,19 +402,22 @@ expr_implicit_intersection (EvalPos const *pos, Value *v)
 	if (start_sheet == end_sheet) {
 		if (rng.start.row == rng.end.row) {
 			int const c = pos->eval.col;
-			if (rng.start.col <= c && c <= rng.end.col)
-				res = value_duplicate (
-					value_area_get_x_y (pos, v,
-							    c - rng.start.col,
-							    0));
+			if (rng.start.col <= c && c <= rng.end.col) {
+				Value const *tmp = value_area_get_x_y (pos, v,
+					c - rng.start.col, 0);
+				if (tmp != NULL)
+					res = value_duplicate (tmp);
+			}
 		}
 
 		if (rng.start.col == rng.end.col) {
 			int const r = pos->eval.row;
-			if (rng.start.row <= r && r <= rng.end.row)
-				res = value_duplicate (
-					value_area_get_x_y (pos, v, 0,
-							    r - rng.start.row));
+			if (rng.start.row <= r && r <= rng.end.row) {
+				Value const *tmp = value_area_get_x_y (pos, v,
+					0, r - rng.start.row);
+				if (tmp != NULL)
+					res = value_duplicate (tmp);
+			}
 		}
 	}
 	value_release (v);
@@ -817,8 +806,14 @@ expr_eval_real (ExprTree const *expr, EvalPos const *pos,
 
 		return res;
 
-	case OPER_FUNCALL:
-		return eval_funcall (pos, expr, flags);
+	case OPER_FUNCALL: {
+		FunctionEvalInfo ei;
+		ei.func_def = expr->func.func;
+		ei.pos = pos;
+
+		/*if (flags & EVAL_PERMIT_NON_SCALAR)*/
+		return function_call_with_list (&ei, expr->func.arg_list);
+	}
 
 	case OPER_NAME:
 		if (expr->name.name->active)
@@ -1184,7 +1179,7 @@ typedef enum {
 
 	/* Both ends of the range must be treated as if they are inside the range */
 	CELLREF_RELOCATE_FORCE_TO_IN,
-	CELLREF_RELOCATE_FORCE_FROM_IN,
+	CELLREF_RELOCATE_FORCE_FROM_IN
 } CellRefRelocate;
 
 /*
