@@ -6,17 +6,17 @@
  * Author:
  *   Miguel de Icaza (miguel@kernel.org)
  */
-#include <config.h>
+#include <gnumeric-config.h>
 #include "gnumeric.h"
+#include "sheet-object-graphic.h"
+
 #include "sheet-control-gui.h"
 #include "gnumeric-canvas.h"
 #include "str.h"
 #include "gui-util.h"
 #include "style-color.h"
-#include "sheet-object-graphic.h"
 #include "sheet-object-impl.h"
 
-#include <libgnome/gnome-defs.h>
 #include <libgnome/gnome-i18n.h>
 #include <gdk/gdkkeysyms.h>
 #include <gal/util/e-util.h>
@@ -479,7 +479,7 @@ sheet_object_graphic_user_config (SheetObject *so, SheetControlGUI *scg)
 					   2, 3, 2, 5);
 	}
 
-	data->fill_color_combo = color_combo_new (NULL, _("Transparent"), NULL,
+	data->fill_color_combo = color_combo_new (NULL, NULL, NULL,
 					color_group_fetch ("color", so));
 	color_combo_set_color (COLOR_COMBO (data->fill_color_combo), 
 			       sog->fill_color ? &sog->fill_color->color : NULL);
